import { OBJECT_TYPE } from 'ferda/RegistryMixin'

export const OBJECT_TITLE_ITEM = Object.freeze({
    CONTACT: 'contact_handle',
    DOMAIN: 'fqdn',
    NSSET: 'nsset_handle',
    KEYSET: 'keyset_handle',
})

export const SearchMixin = {
    created() {
        this.OBJECT_TITLE_ITEM = OBJECT_TITLE_ITEM
    },

    methods: {
        get_match_keys(result) {
            if (result.match_keys) {
                return result.match_keys
            } else if (result.histories) {
                const last_match = result.histories[result.histories.length - 1]
                if (!last_match.valid_to) {
                    return last_match.match_keys
                } else if (result.events.unregistered && result.events.unregistered.timestamp === last_match.valid_to) {
                    return last_match.match_keys
                }
            }
            return {}
        },

        match_item_label(match, object_type) {
            const item = match.split('.').pop()
            if (object_type === OBJECT_TYPE.CONTACT) {
                const contact_item = match.split('.')[0]
                if (contact_item === 'additional_identifier') {
                    return `${this.$t(`contact:${contact_item}`)} (${this.$t(`contact:identifier_type.${item}`)})`
                } else {
                    return this.$t(`contact:${contact_item}`)
                }
            } else if (object_type === OBJECT_TYPE.DOMAIN) {
                return this.$t(`domain:${item}`)
            } else if (object_type === OBJECT_TYPE.NSSET) {
                return this.$t(`nsset:${item}`)
            } else if (object_type === OBJECT_TYPE.KEYSET) {
                return this.$t(`keyset:${item}`)
            }
        },
    },
}
