"""Registry domain schemas."""
from datetime import datetime
from typing import Dict, List, Optional

import regal
from ninja import Schema
from regal import ContactId, DomainId
from regal.domain import ContactInfo, DomainContactRole


# XXX: This is a temporary fix until related object handles are added to the API
class Domain(regal.Domain):
    """Domain with related object handles."""

    keyset_handle: Optional[str] = None
    nsset_handle: Optional[str] = None


class DomainByContact(Schema):
    """Domain by contact schema."""

    domain: Domain
    roles: List[DomainContactRole] = []


class DomainContactInfo(Schema):
    """Domain contact info."""

    domain_id: DomainId
    fqdn: str
    registrant_id: ContactId
    registrant_handle: str
    registrant_name: str
    registrant_organization: str
    contacts: List[ContactInfo]
    additional_contacts: List[ContactInfo]


class UpdateDomainAdditionalContacts(Schema):
    """Additional domain contacts for outzone or delete warning."""

    domains: Dict[DomainId, List[ContactInfo]]
    start: datetime
    end: datetime
